<?php
/*
Plugin Name: LJ Multi Column Archive
Plugin URI: http://www.thelazysysadmin.net/software/wordpress-plugins/lj-multi-column-archive/
Description: LJ Multi Column Archive is a Wordpress plugin/widget that allows you to display your archive list with multiple columns. I developed this plugin as I wanted to make use of the space I had in the sidebar more effectively.
Author: Jon Smith
Version: 1.1a
Author URI: http://www.thelazysysadmin.net/
*/

function LJMultiColumnArchive_widget($args) {
  global $wpdb, $wp_locale;

  extract($args);

  $opt_title = get_option('widget-LJMultiColumnArchive-title');
  $opt_showpostcount = get_option('widget-LJMultiColumnArchive-showpostcount');
  $opt_numcolumns = get_option('widget-LJMultiColumnArchive-numcolumns');

  if ($opt_title == "") {
    $opt_title = "Archives";
  }

  if ($opt_showpostcount == "") {
    $opt_showpostcount = "0";
  }

  if ($opt_numcolumns == "") {
    $opt_numcolumns = "1";
  }

  $query = "SELECT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, count(ID) as posts FROM $wpdb->posts WHERE post_type = 'post' AND post_status = 'publish' GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date DESC";
  $key = md5($query);
  $cache = wp_cache_get( 'LJMultiColumnArchive_widget' , 'general');
  if ( !isset( $cache[ $key ] ) ) {
    $arcresults = $wpdb->get_results($query);
    $cache[ $key ] = $arcresults;
    wp_cache_add( 'LJMultiColumnArchive_widget', $cache, 'general' );
  } else {
    $arcresults = $cache[ $key ];
  }
  if ( $arcresults ) {
    $afterafter = $after;
    $i = 0;
    foreach ( (array) $arcresults as $arcresult ) {
      $output[$i]['url'] = get_month_link( $arcresult->year, $arcresult->month );
      $output[$i]['text'] = sprintf(__('%1$s %2$d'), $wp_locale->get_month($arcresult->month), $arcresult->year);
      $output[$i]['postcount'] = $arcresult->posts;
      if ($opt_showpostcount == "1") {
        $after = '&nbsp;('.$arcresult->posts.')';
      }
      $output[$i]['link'] = get_archives_link($output[$i]['url'], $output[$i]['text'], 'html', '', $after);
      $i++;
    }
  }

  echo $before_widget;
  echo "<h3>".$opt_title."</h3>\n";
  echo "<div class='ljmulticolumnarchive-box'>\n";

  $count = count($output);
  $mod = ceil($count / $opt_numcolumns);

  $i = 0;
  foreach ($output as $item) {
    if (($i % $mod) == 0) {
      echo "  <div class='ljmulticolumnarchive-section";
      if ($i > 0) {
        echo " ljmulticolumnarchive-section-next";
      }
      echo "'>\n";
      echo "    <ul>\n";
    }

    echo "      ".$item['link'];

    if ((($i+1) % $mod) == 0) {
      echo "    </ul>\n";
      echo "  </div>\n";
    }

    $i++;
  }

  if ((($i) % $mod) != 0) {
    echo "    </ul>\n";
    echo "  </div>\n";
  }

  echo "</div>\n";
  echo "<div class='ljmulticolumnarchive-clear'></div>\n";
  echo $after_widget;

}

function LJMultiColumnArchive_widget_control() {

  if ($_POST['widget-LJMultiColumnArchive-submit']) {
    update_option('widget-LJMultiColumnArchive-title', $_POST['widget-LJMultiColumnArchive-title']);
    update_option('widget-LJMultiColumnArchive-showpostcount', $_POST['widget-LJMultiColumnArchive-showpostcount']);
    update_option('widget-LJMultiColumnArchive-numcolumns', $_POST['widget-LJMultiColumnArchive-numcolumns']);
  }

  $opt_title = get_option('widget-LJMultiColumnArchive-title');
  $opt_showpostcount = get_option('widget-LJMultiColumnArchive-showpostcount');
  $opt_numcolumns = get_option('widget-LJMultiColumnArchive-numcolumns');

  if ($opt_title == "") {
    $opt_title = "Archives";
  }

  if ($opt_showpostcount == "") {
    $opt_showpostcount = "0";
  }

  if ($opt_numcolumns == "") {
    $opt_numcolumns = "1";
  }

  echo '<p><label for="widget-LJMultiColumnArchive-title">Title: <br />';
  echo '<input type="text" class="widefat" id="widget-LJMultiColumnArchive-title" name="widget-LJMultiColumnArchive-title" value="'.$opt_title.'" /></label></p>';

  echo '<p><input type="checkbox" name="widget-LJMultiColumnArchive-showpostcount" id="widget-LJMultiColumnArchive-showpostcount" value="1"';
  if ($opt_showpostcount == "1") { echo 'checked'; }
  echo '><label for="widget-LJMultiColumnArchive-showpostcount">&nbsp;Show Post Count</label></p>';

  echo '<p><label for="widget-LJMultiColumnArchive-numcolumns">Num of Columns:</label><br/>';
  echo '<input type="radio" name="widget-LJMultiColumnArchive-numcolumns" id="widget-LJMultiColumnArchive-numcolumns" value="1"';
  if ($opt_numcolumns == "1") { echo 'checked="checked"'; }
  echo '>One&nbsp;<input type="radio" name="widget-LJMultiColumnArchive-numcolumns" id="widget-LJMultiColumnArchive-numcolumns" value="2"';
  if ($opt_numcolumns == "2") { echo 'checked="checked"'; }
  echo '>Two&nbsp;<input type="radio" name="widget-LJMultiColumnArchive-numcolumns" id="widget-LJMultiColumnArchive-numcolumns" value="3"';
  if ($opt_numcolumns == "3") { echo 'checked="checked"'; }
  echo '>Three</p>';

  echo '<input type="hidden" id="widget-LJMultiColumnArchive-submit" name="widget-LJMultiColumnArchive-submit" value="1" />';

}

function LJMultiColumnArchive_add_styles() {
  $stylesheet = "/lj-multi-column-archive/css/lj-multi-column-archive.css";
  $stylesheeturl = WP_PLUGIN_URL.$stylesheet;
  $stylesheetfile = WP_PLUGIN_DIR.$stylesheet;
  if (file_exists($stylesheetfile)) {
    wp_register_style("LJMultiColumnArchiveStyleSheet", $stylesheeturl);
    wp_enqueue_style("LJMultiColumnArchiveStyleSheet");
  }
}

function init_LJMultiColumnArchive() {
  register_sidebar_widget("LJ Multi Column Archive", "LJMultiColumnArchive_widget");

  register_widget_control("LJ Multi Column Archive", "LJMultiColumnArchive_widget_control");

  add_action('wp_print_styles', 'LJMultiColumnArchive_add_styles');
}

add_action("plugins_loaded", "init_LJMultiColumnArchive");

?>